pub fn validate_uuid(value: &str, field_name: &str) -> Result<(), StackureError>Expand description
Validate that a string is a valid UUID v4.
Errors
Returns StackureError::Validation if the value is empty or not a valid UUID v4.
pub fn validate_uuid(value: &str, field_name: &str) -> Result<(), StackureError>Validate that a string is a valid UUID v4.
Returns StackureError::Validation if the value is empty or not a valid UUID v4.